---------------------------------------------------------------------------
--                                                                       --
--         Cfg2Dot generates dot output for a CFG using Ast2Cfg          --
--                          http://cfg.w3x.org                           --
--                                                                       --
---------------------------------------------------------------------------
--                                                                       --
--          Copyright (c) 2007, Raul Fechete, Georg Kienesberger         --
--                                                                       --
---------------------------------------------------------------------------
--                                                                       --
-- This file is part of Cfg2Dot.                                         --
--                                                                       --
-- Cfg2Dot is free software; you can redistribute it and/or modify       --
-- it under the terms of the GNU General Public License as published by  --
-- the Free Software Foundation; either version 3 of the License, or     --
-- (at your option) any later version.                                   --
--                                                                       --
-- Cfg2Dot is distributed in the hope that it will be useful,            --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of        --
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         --
-- GNU General Public License for more details.                          --
--                                                                       --
-- You should have received a copy of the GNU General Public License     --
-- along with this program.  If not, see <http://www.gnu.org/licenses/>. --
--                                                                       --
---------------------------------------------------------------------------

with Ada.Exceptions;
with Ada.Text_IO; use Ada.Text_IO;
with Ada.Strings.Unbounded; use Ada.Strings.Unbounded;
with Ada.Characters.Handling; use Ada.Characters.Handling;

with Ast2Cfg.Control;
with Ast2Cfg.Flow_World;
with Ast2Cfg.Output;

with Cfg_To_Dot.Options;
with Cfg_To_Dot.Output; use Cfg_To_Dot.Output;

package body Cfg_To_Dot is
   procedure Run is
      World: Ast2Cfg.Flow_World.World_Object_Ptr;
   begin

      -- Initializations
      case Options.Verbosity is
         when 0 =>
            Ast2Cfg.Output.Set_Level(Ast2Cfg.Output.Warning);
         when 1 =>
            Ast2Cfg.Output.Set_Level(Ast2Cfg.Output.Debug);
         when 2 =>
            Ast2Cfg.Output.Set_Level(Ast2Cfg.Output.Max);
      end case;
      Ast2Cfg.Control.Init(To_Wide_String(To_String(Options.Context_Parameters)));

      -- Fill the World with flow data
      World := Ast2Cfg.Control.Generate;

      -- Utilize the Flow World
      World_Dot_Dump(World.all);

      -- Finalization
      Ast2Cfg.Control.Final;

   exception
      when Ex : others =>

         Put_Line(Standard_Error, "ERROR: " &
                  Ada.Exceptions.Exception_Name(Ex) &
                  ": " &
                  Ada.Exceptions.Exception_Information(Ex));

   end Run;
end Cfg_To_Dot;
